// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef PULSEAUDIOQT_VERSION_H
#define PULSEAUDIOQT_VERSION_H

#define PULSEAUDIOQT_VERSION_STRING "1.3.0"
#define PULSEAUDIOQT_VERSION_MAJOR 1
#define PULSEAUDIOQT_VERSION_MINOR 3
#define PULSEAUDIOQT_VERSION_PATCH 0
#define PULSEAUDIOQT_VERSION ((1<<16)|(3<<8)|(0))

#endif
